#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ral
version:              0.2.2
visibility:           public
id:                   ral-0.2.2-FTQ25hDKmgJIUEVLvJ4gIF
key:                  ral-0.2.2-FTQ25hDKmgJIUEVLvJ4gIF
license:              GPL-2.0-or-later
copyright:            (c) 2019-2021 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/vec
synopsis:             Random access lists
description:
    This package provides ordinary random access list, '\''RAList'\'', and also
    a length indexed variant, '\''RAVec'\''.

    The data structure allows fast cons-operation (like ordinary list) but also fast random access (like non-functional arrays).

    For @lens@ or @optics@ support see [ral-lens](https://hackage.haskell.org/package/ral-lens) and [ral-optics](https://hackage.haskell.org/package/ral-optics) packages respectively.

    === Similar packages

    These packages don'\''t provide length-indexed variants, and their '\''RAList'\'' has
    opaque structure.

    * https://hackage.haskell.org/package/ralist
    * https://hackage.haskell.org/package/random-access-list

category:             Data, Dependent Types, Singletons
abi:                  61779c0994e371ee39500017f0ca7364
exposed:              True
exposed-modules:
    Data.RAList Data.RAList.NonEmpty Data.RAList.Tree Data.RAVec
    Data.RAVec.NonEmpty Data.RAVec.Tree Data.RAVec.Tree.DF

hidden-modules:
    Data.RAList.Internal Data.RAList.NonEmpty.Internal
    Data.RAList.Tree.Internal TrustworthyCompat

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ral-0.2.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ral-0.2.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ral-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ral
hs-libraries:         HSral-0.2.2-FTQ25hDKmgJIUEVLvJ4gIF
depends:
    QuickCheck-2.15.0.1-Erpv4AOLtST7sTBBKJurVZ
    adjunctions-4.4.4-66BkvlzLLTw3SGXF3BB87S base-4.18.2.1
    bin-0.1.4.1-DXmRlUtE12aKyA8YcKG0e9
    boring-0.2.2-2aq1ciWPNkQB31v6aiIRKA deepseq-1.4.8.1
    distributive-0.6.2.1-72dKYBChrKvxwuYriLPTp
    fin-0.3.2-FC0dKn02XPB5mybJLoBmao
    hashable-1.4.7.0-LB47rq9amzm4H74gyqVlYy
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    semigroupoids-6.0.2-Jr2GQOpPKK2GhToutg8VY0

haddock-interfaces:   /usr/share/doc/haskell-ral/html/ral.haddock
haddock-html:         /usr/share/doc/haskell-ral/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

